﻿using System.Collections.Generic;
using System.Windows.Forms;

using DevExpress.Utils;
using DevExpress.XtraEditors;
using DevExpress.XtraGrid.Views.Base;
using DevExpress.XtraGrid.Views.Grid;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            #region 그리드 컨트롤을 설정한다.

            this.gridView.OptionsDetail.EnableMasterViewMode = false;
            this.gridView.OptionsSelection.MultiSelect       = true;
            this.gridView.OptionsSelection.MultiSelectMode   = GridMultiSelectMode.CellSelect;
            this.gridView.FocusRectStyle                     = DrawFocusRectStyle.CellFocus;

            this.gridView.OptionsView.ShowGroupPanel = false;

            this.gridView.IndicatorWidth                         = 30;
            this.gridView.OptionsView.ShowIndicator              = true;
            this.gridView.OptionsView.EnableAppearanceEvenRow    = false;
            this.gridView.OptionsView.EnableAppearanceOddRow     = false;
            this.gridView.OptionsBehavior.KeepFocusedRowOnUpdate = false;
            this.gridView.OptionsNavigation.AutoFocusNewRow      = true;

            this.gridView.OptionsBehavior.AutoPopulateColumns      = true;
            this.gridView.OptionsView.ShowColumnHeaders            = true;
            this.gridView.OptionsView.ColumnAutoWidth              = false;
            this.gridView.OptionsMenu.EnableColumnMenu             = false;
            this.gridView.OptionsNavigation.EnterMoveNextColumn    = true;
            this.gridView.OptionsCustomization.AllowColumnMoving   = false;
            this.gridView.OptionsCustomization.AllowColumnResizing = true;
            this.gridView.OptionsCustomization.AllowFilter         = false;
            this.gridView.OptionsCustomization.AllowSort           = false;

            this.gridView.OptionsView.ShowButtonMode                   = ShowButtonModeEnum.ShowForFocusedCell;
            this.gridView.OptionsView.AllowCellMerge                   = false;
            this.gridView.OptionsBehavior.EditorShowMode               = EditorShowMode.Default;
            this.gridView.OptionsBehavior.Editable                     = true;
            this.gridView.OptionsSelection.EnableAppearanceFocusedCell = false;
            this.gridView.OptionsSelection.InvertSelection             = false;
            this.gridView.OptionsHint.ShowCellHints                    = false;
            this.gridView.OptionsClipboard.CopyColumnHeaders           = DefaultBoolean.False;

            #endregion

            List<Employee> sourceList = Employee.GetList();

            this.gridControl.DataSource = sourceList;

            this.dataNavigator.DataSource = sourceList;

            this.dataNavigator.ButtonClick += dataNavigator_ButtonClick;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 데이터 네비게이터 버튼 클릭시 처리하기 - dataNavigator_ButtonClick(sender, e)

        /// <summary>
        /// 데이터 네비게이터 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void dataNavigator_ButtonClick(object sender, NavigatorButtonClickEventArgs e)
        {
            if(e.Button.ButtonType == NavigatorButtonType.Remove)
            {
                DialogResult result = XtraMessageBox.Show
                (
                    this,
                    "레코드를 삭제하시겠습니까?",
                    "CONFIRMATION",
                    MessageBoxButtons.YesNo,
                    MessageBoxIcon.Question
                );

                if(result == DialogResult.No)
                {
                    e.Handled = true;
                }
            }
        }

        #endregion
    }
}